# coding: utf-8

# flake8: noqa
"""
    Power Platform Connector

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from allen_powerplatform_client.models.get_table_request import GetTableRequest
from allen_powerplatform_client.models.post_water_record_request import PostWaterRecordRequest
from allen_powerplatform_client.models.post_weight_record_request import PostWeightRecordRequest
