# coding: utf-8

"""
    Power Platform Connector

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from allen_powerplatform_client.api.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()

    def tearDown(self) -> None:
        pass

    def test_fetch_table_names(self) -> None:
        """Test case for fetch_table_names

        Get Table Names Power Automate Flow
        """
        pass

    def test_get_table(self) -> None:
        """Test case for get_table

        Gets all data for a table by table name
        """
        pass

    def test_post_water_record(self) -> None:
        """Test case for post_water_record

        Posts a water record from WaterLog into the dataverse weights water table
        """
        pass

    def test_post_weight_record(self) -> None:
        """Test case for post_weight_record

        Posts a weight record from water log
        """
        pass


if __name__ == '__main__':
    unittest.main()
